'use strict';

var fs = require('fs');
var path = require('path');
var webpack = require('webpack');

var config = {
  entry:  './browser-entry.js' ,
  output: { filename : 'mocha.js' },
  resolve: {
        modules: process.env.NODE_PATH.split(':')
  },
  resolveLoader: {
        modules: process.env.NODE_PATH.split(':')
  },
  node: {
    fs: 'empty',
    glob: 'empty',
    path: 'empty',
  }
}

module.exports = config;
